@@ -1,4 +1,4 @@
-var allDescriptors=[{"dependencies":[],"name":"platform","scripts":[]},{"dependencies":["platform"],"name":"toolbox_bootstrap","scripts":[]}];var applicationDescriptor;var _loadedScripts={};for(var k of[]);function loadResourcePromise(url)
+var allDescriptors=[{"dependencies":[],"name":"platform","scripts":[]},{"dependencies":["platform"],"name":"toolbox_bootstrap","scripts":[]}];var applicationDescriptor;var _loadedScripts={};for(var k of[]){};function loadResourcePromise(url)
 {return new Promise(load);function load(fulfill,reject)
 {var xhr=new XMLHttpRequest();xhr.open("GET",url,true);xhr.onreadystatechange=onreadystatechange;function onreadystatechange(e)
 {if(xhr.readyState!==4)
@@ -61,7 +61,7 @@ function handler(index,e)
 {wasRejected[index]=true;console.error(e.stack);}}
 Runtime._console=console;Runtime._originalAssert=console.assert;Runtime._assert=function(value,message)
 {if(value)
-return;Runtime._originalAssert.call(Runtime._console,value,message);}
+return;Runtime._originalAssert.call(Runtime._console,value,message+" "+new Error().stack);}
 Runtime.prototype={useTestBase:function()
 {Runtime._remoteBase="http://localhost:8000/inspector-sources/";},_registerModule:function(descriptor)
 {var module=new Runtime.Module(this,descriptor);this._modules.push(module);this._modulesMap[descriptor["name"]]=module;},loadModulePromise:function(moduleName)
@@ -107,32 +107,38 @@ Runtime.Module.prototype={name:function()
 {return this._name;},enabled:function()
 {var activatorExperiment=this._descriptor["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
 return false;var condition=this._descriptor["condition"];if(condition&&!Runtime.queryParam(condition))
-return false;return true;},_loadPromise:function()
+return false;return true;},resource:function(name)
+{var fullName=this._name+"/"+name;var content=Runtime.cachedResources[fullName];if(!content)
+throw new Error(fullName+" not preloaded. Check module.json");return content;},_loadPromise:function()
 {if(this._loaded)
 return Promise.resolve();if(!this.enabled())
 return Promise.reject(new Error("Module "+this._name+" is not enabled"));if(this._pendingLoadPromise)
 return this._pendingLoadPromise;var dependencies=this._descriptor.dependencies;var dependencyPromises=[];for(var i=0;dependencies&&i<dependencies.length;++i)
-dependencyPromises.push(this._manager._modulesMap[dependencies[i]]._loadPromise());this._pendingLoadPromise=Promise.all(dependencyPromises).then(this._loadStylesheets.bind(this)).then(this._loadScripts.bind(this)).then(markAsLoaded.bind(this));return this._pendingLoadPromise;function markAsLoaded()
-{delete this._pendingLoadPromise;this._loaded=true;}},_loadStylesheets:function()
-{var stylesheets=this._descriptor["stylesheets"];if(!stylesheets)
-return Promise.resolve();var promises=[];for(var i=0;i<stylesheets.length;++i){var url=this._modularizeURL(stylesheets[i]);promises.push(loadResourcePromise(url).then(cacheStylesheet.bind(this,url),cacheStylesheet.bind(this,url,undefined)));}
-return Promise.all(promises).then(undefined);function cacheStylesheet(path,content)
-{if(!content){console.error("Failed to load stylesheet: "+path);return;}
+dependencyPromises.push(this._manager._modulesMap[dependencies[i]]._loadPromise());this._pendingLoadPromise=Promise.all(dependencyPromises).then(this._loadResources.bind(this)).then(this._loadScripts.bind(this)).then(markAsLoaded.bind(this));return this._pendingLoadPromise;function markAsLoaded()
+{delete this._pendingLoadPromise;this._loaded=true;}},_loadResources:function()
+{var resources=this._descriptor["resources"];if(!resources)
+return Promise.resolve();var promises=[];for(var i=0;i<resources.length;++i){var url=this._modularizeURL(resources[i]);promises.push(loadResourcePromise(url).then(cacheResource.bind(this,url),cacheResource.bind(this,url,undefined)));}
+return Promise.all(promises).then(undefined);function cacheResource(path,content)
+{if(!content){console.error("Failed to load resource: "+path);return;}
 var sourceURL=window.location.href;if(window.location.search)
 sourceURL=sourceURL.replace(window.location.search,"");sourceURL=sourceURL.substring(0,sourceURL.lastIndexOf("/")+1)+path;Runtime.cachedResources[path]=content+"\n/*# sourceURL="+sourceURL+" */";}},_loadScripts:function()
 {if(!this._descriptor.scripts)
-return Promise.resolve();if(Runtime.isReleaseMode()){var base=this._descriptor.remote&&Runtime._remoteBase||undefined;return loadScriptsPromise([this._name+"_module.js"],base);}
-return loadScriptsPromise(this._descriptor.scripts.map(this._modularizeURL,this));},_modularizeURL:function(resourceName)
-{return normalizePath(this._name+"/"+resourceName);},_instance:function(className)
+return Promise.resolve();if(Runtime.isReleaseMode())
+return loadScriptsPromise([this._name+"_module.js"],this._remoteBase());return loadScriptsPromise(this._descriptor.scripts.map(this._modularizeURL,this));},_modularizeURL:function(resourceName)
+{return normalizePath(this._name+"/"+resourceName);},_remoteBase:function()
+{return this._descriptor.remote&&Runtime._remoteBase||undefined;},substituteURL:function(value)
+{var base=this._remoteBase()||"";return value.replace(/@url\(([^\)]*?)\)/g,convertURL.bind(this));function convertURL(match,url)
+{return base+this._modularizeURL(url);}},_instance:function(className,extension)
 {if(className in this._instanceMap)
 return this._instanceMap[className];var constructorFunction=window.eval(className);if(!(constructorFunction instanceof Function)){this._instanceMap[className]=null;return null;}
-var instance=new constructorFunction();this._instanceMap[className]=instance;return instance;}}
+var instance=new constructorFunction(extension);this._instanceMap[className]=instance;return instance;}}
 Runtime.Extension=function(module,descriptor)
 {this._module=module;this._descriptor=descriptor;this._type=descriptor.type;this._hasTypeClass=this._type.charAt(0)==="@";this._className=descriptor.className||null;}
 Runtime.Extension.prototype={descriptor:function()
 {return this._descriptor;},module:function()
 {return this._module;},enabled:function()
-{var activatorExperiment=this.descriptor()["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
+{var activatorExperiment=this.descriptor()["experiment"];if(activatorExperiment&&activatorExperiment.startsWith("!")&&Runtime.experiments.isEnabled(activatorExperiment.substring(1)))
+return false;if(activatorExperiment&&!activatorExperiment.startsWith("!")&&!Runtime.experiments.isEnabled(activatorExperiment))
 return false;var condition=this.descriptor()["condition"];if(condition&&!Runtime.queryParam(condition))
 return false;return this._module.enabled();},_typeClass:function()
 {if(!this._hasTypeClass)
@@ -141,8 +147,9 @@ return null;return this._module._manager._resolve(this._type.substring(1));},isA
 {if(!this._className)
 return Promise.reject(new Error("No class name in extension"));var className=this._className;if(this._instance)
 return Promise.resolve(this._instance);return this._module._loadPromise().then(constructInstance.bind(this));function constructInstance()
-{var result=this._module._instance(className);if(!result)
-return Promise.reject("Could not instantiate: "+className);return result;}}}
+{var result=this._module._instance(className,this);if(!result)
+return Promise.reject("Could not instantiate: "+className);return result;}},title:function(platform)
+{return this._descriptor["title-"+platform]||this._descriptor["title"];}}
 Runtime.ExperimentsSupport=function()
 {this._supportEnabled=Runtime.queryParam("experiments")!==null;this._experiments=[];this._experimentNames={};this._enabledTransiently={};}
 Runtime.ExperimentsSupport.prototype={allConfigurableExperiments:function()
@@ -158,7 +165,8 @@ return true;if(!this.supportEnabled())
 return false;return!!Runtime._experimentsSetting()[experimentName];},setEnabled:function(experimentName,enabled)
 {this._checkExperiment(experimentName);var experimentsSetting=Runtime._experimentsSetting();experimentsSetting[experimentName]=enabled;this._setExperimentsSetting(experimentsSetting);},setDefaultExperiments:function(experimentNames)
 {for(var i=0;i<experimentNames.length;++i){this._checkExperiment(experimentNames[i]);this._enabledTransiently[experimentNames[i]]=true;}},enableForTest:function(experimentName)
-{this._checkExperiment(experimentName);this._enabledTransiently[experimentName]=true;},cleanUpStaleExperiments:function()
+{this._checkExperiment(experimentName);this._enabledTransiently[experimentName]=true;},clearForTest:function()
+{this._experiments=[];this._experimentNames={};this._enabledTransiently={};},cleanUpStaleExperiments:function()
 {var experimentsSetting=Runtime._experimentsSetting();var cleanedUpExperimentSetting={};for(var i=0;i<this._experiments.length;++i){var experimentName=this._experiments[i].name;if(experimentsSetting[experimentName])
 cleanedUpExperimentSetting[experimentName]=true;}
 this._setExperimentsSetting(cleanedUpExperimentSetting);},_checkExperiment:function(experimentName)
@@ -170,10 +178,11 @@ Runtime.Experiment.prototype={isEnabled:function()
 {this._experiments.setEnabled(this.name,enabled);}}
 {(function parseQueryParameters()
 {var queryParams=location.search;if(!queryParams)
-return;var params=queryParams.substring(1).split("&");for(var i=0;i<params.length;++i){var pair=params[i].split("=");var name=pair.shift();Runtime._queryParamsObject[name]=pair.join("=");}
-var settingsParam=Runtime.queryParam("settings");if(settingsParam){try{var settings=JSON.parse(window.decodeURI(settingsParam));for(var key in settings)
-window.localStorage[key]=settings[key];}catch(e){}}})();}
-Runtime.experiments=new Runtime.ExperimentsSupport();Runtime._remoteBase=Runtime.queryParam("remoteBase");var runtime;console=console;console.__originalAssert=console.assert;console.assert=function(value,message)
+return;var params=queryParams.substring(1).split("&");for(var i=0;i<params.length;++i){var pair=params[i].split("=");var name=pair.shift();Runtime._queryParamsObject[name]=pair.join("=");}})();}
+Runtime.experiments=new Runtime.ExperimentsSupport();Runtime._remoteBase=Runtime.queryParam("remoteBase");{(function validateRemoteBase()
+{if(Runtime._remoteBase&&!Runtime._remoteBase.startsWith("https://chrome-devtools-frontend.appspot.com/"))
+Runtime._remoteBase=null;})();}
+var runtime;console=console;console.__originalAssert=console.assert;console.assert=function(value,message)
 {if(value)
 return;console.__originalAssert(value,message);}
 var ArrayLike;Object.isEmpty=function(obj)
@@ -232,10 +241,6 @@ function sanitizeHref(href)
 String.prototype.removeURLFragment=function()
 {var fragmentIndex=this.indexOf("#");if(fragmentIndex==-1)
 fragmentIndex=this.length;return this.substring(0,fragmentIndex);}
-String.prototype.startsWith=function(substring)
-{return!this.lastIndexOf(substring,0);}
-String.prototype.endsWith=function(substring)
-{return this.indexOf(substring,this.length-substring.length)!==-1;}
 String.hashCode=function(string)
 {if(!string)
 return 0;var result=0;for(var i=0;i<string.length;++i)
@@ -245,15 +250,11 @@ String.isDigitAt=function(string,index)
 String.prototype.toBase64=function()
 {function encodeBits(b)
 {return b<26?b+65:b<52?b+71:b<62?b-4:b===62?43:b===63?47:65;}
-var data=this.toUint8Array();var n=data.length;var encoded="";if(n===0)
+var encoder=new TextEncoder();var data=encoder.encode(this.toString());var n=data.length;var encoded="";if(n===0)
 return encoded;var shift;var v=0;for(var i=0;i<n;i++){shift=i%3;v|=data[i]<<(16>>>shift&24);if(shift===2){encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),encodeBits(v>>>6&63),encodeBits(v&63));v=0;}}
 if(shift===0)
 encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),61,61);else if(shift===1)
 encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),encodeBits(v>>>6&63),61);return encoded;}
-String.prototype.toUint8Array=function()
-{var n=this.length;var dataLen=0;for(var i=0;i<n;++i){var c=this.charCodeAt(i);dataLen+=c<0x80?1:c<0x800?2:c<0x10000?3:c<0x200000?4:c<0x4000000?5:6;}
-var data=new Uint8Array(dataLen);var j=0;for(var i=0;i<n;++i){var c=this.charCodeAt(i);if(c<0x80){data[j++]=c;}else if(c<0x800){data[j++]=192+(c>>>6);data[j++]=128+(c&63);}else if(c<0x10000){data[j++]=224+(c>>>12);data[j++]=128+(c>>>6&63);data[j++]=128+(c&63);}else if(c<0x200000){data[j++]=240+(c>>>18);data[j++]=128+(c>>>12&63);data[j++]=128+(c>>>6&63);data[j++]=128+(c&63);}else if(c<0x4000000){data[j++]=248+(c>>>24);data[j++]=128+(c>>>18&63);data[j++]=128+(c>>>12&63);data[j++]=128+(c>>>6&63);data[j++]=128+(c&63);}else{data[j++]=252+(c>>>30);data[j++]=128+(c>>>24&63);data[j++]=128+(c>>>18&63);data[j++]=128+(c>>>12&63);data[j++]=128+(c>>>6&63);data[j++]=128+(c&63);}}
-return data;}
 String.naturalOrderComparator=function(a,b)
 {var chunk=/^\d+|^\D+/;var chunka,chunkb,anum,bnum;while(1){if(a){if(!b)
 return 1;}else{if(b)
@@ -300,10 +301,10 @@ leadZero2(this.getSeconds())+"."+
 leadZero3(this.getMilliseconds());}
 Object.defineProperty(Array.prototype,"remove",{value:function(value,firstOnly)
 {var index=this.indexOf(value);if(index===-1)
-return;if(firstOnly){this.splice(index,1);return;}
+return false;if(firstOnly){this.splice(index,1);return true;}
 for(var i=index+1,n=this.length;i<n;++i){if(this[i]!==value)
 this[index++]=this[i];}
-this.length=index;}});Object.defineProperty(Array.prototype,"keySet",{value:function()
+this.length=index;return true;}});Object.defineProperty(Array.prototype,"keySet",{value:function()
 {var keys={};for(var i=0;i<this.length;++i)
 keys[this[i]]=true;return keys;}});Object.defineProperty(Array.prototype,"pushAll",{value:function(array)
 {Array.prototype.push.apply(this,array);}});Object.defineProperty(Array.prototype,"rotate",{value:function(index)
@@ -374,7 +375,9 @@ String.sprintf=function(format,var_arg)
 {return String.vsprintf(format,Array.prototype.slice.call(arguments,1));}
 String.tokenizeFormatString=function(format,formatters)
 {var tokens=[];var substitutionIndex=0;function addStringToken(str)
-{tokens.push({type:"string",value:str});}
+{if(tokens.length&&tokens[tokens.length-1].type==="string")
+tokens[tokens.length-1].value+=str;else
+tokens.push({type:"string",value:str});}
 function addSpecifierToken(specifier,precision,substitutionIndex)
 {tokens.push({type:"specifier",specifier:specifier,precision:precision,substitutionIndex:substitutionIndex});}
 var index=0;for(var precentIndex=format.indexOf("%",index);precentIndex!==-1;precentIndex=format.indexOf("%",index)){if(format.length===index)
@@ -463,7 +466,9 @@ function CallbackBarrier()
 CallbackBarrier.prototype={createCallback:function(userCallback)
 {console.assert(!this._outgoingCallback,"CallbackBarrier.createCallback() is called after CallbackBarrier.callWhenDone()");++this._pendingIncomingCallbacksCount;return this._incomingCallback.bind(this,userCallback);},callWhenDone:function(callback)
 {console.assert(!this._outgoingCallback,"CallbackBarrier.callWhenDone() is called multiple times");this._outgoingCallback=callback;if(!this._pendingIncomingCallbacksCount)
-this._outgoingCallback();},_incomingCallback:function(userCallback)
+this._outgoingCallback();},donePromise:function()
+{return new Promise(promiseConstructor.bind(this));function promiseConstructor(success)
+{this.callWhenDone(success);}},_incomingCallback:function(userCallback)
 {console.assert(this._pendingIncomingCallbacksCount>0);if(userCallback){var args=Array.prototype.slice.call(arguments,1);userCallback.apply(null,args);}
 if(!--this._pendingIncomingCallbacksCount&&this._outgoingCallback)
 this._outgoingCallback();}}
@@ -473,7 +478,8 @@ self.setImmediate=function(callback)
 {Promise.resolve().then(callback);return 0;}
 Promise.prototype.spread=function(callback)
 {return this.then(spreadPromise);function spreadPromise(arg)
-{return callback.apply(null,arg);}};Node.prototype.rangeOfWord=function(offset,stopCharacters,stayWithinNode,direction)
+{return callback.apply(null,arg);}}
+Promise.prototype.catchException=function(defaultValue){return this.catch(function(error){console.error(error);return defaultValue;});};Node.prototype.rangeOfWord=function(offset,stopCharacters,stayWithinNode,direction)
 {var startNode;var startOffset=0;var endNode;var endOffset=0;if(!stayWithinNode)
 stayWithinNode=this;if(!direction||direction==="backward"||direction==="both"){var node=this;while(node){if(node===stayWithinNode){if(!startNode)
 startNode=stayWithinNode;break;}
@@ -498,9 +504,11 @@ shift=relativeTo.boxInWindow(this.ownerDocument.defaultView);if(typeof x==="numb
 this.style.setProperty("left",(shift.x+x)+"px");else
 this.style.removeProperty("left");if(typeof y==="number")
 this.style.setProperty("top",(shift.y+y)+"px");else
-this.style.removeProperty("top");}
+this.style.removeProperty("top");if(typeof x==="number"||typeof y==="number")
+this.style.setProperty("position","absolute");else
+this.style.removeProperty("position");}
 Element.prototype.isScrolledToBottom=function()
-{return Math.abs(this.scrollTop+this.clientHeight-this.scrollHeight)<=1;}
+{return Math.abs(this.scrollTop+this.clientHeight-this.scrollHeight)<=2;}
 function removeSubsequentNodes(fromNode,toNode)
 {for(var node=fromNode;node&&node!==toNode;){var nodeToRemove=node;node=node.nextSibling;nodeToRemove.remove();}}
 Element.prototype.containsEventPoint=function(event)
@@ -569,10 +577,7 @@ DocumentFragment.prototype.createChild=Element.prototype.createChild;Element.pro
 DocumentFragment.prototype.createTextChild=Element.prototype.createTextChild;Element.prototype.createTextChildren=function(var_args)
 {for(var i=0,n=arguments.length;i<n;++i)
 this.createTextChild(arguments[i]);}
-DocumentFragment.prototype.createTextChildren=Element.prototype.createTextChildren;Element.prototype.appendChildren=function(var_args)
-{for(var i=0,n=arguments.length;i<n;++i)
-this.appendChild(arguments[i]);}
-Element.prototype.totalOffsetLeft=function()
+DocumentFragment.prototype.createTextChildren=Element.prototype.createTextChildren;Element.prototype.totalOffsetLeft=function()
 {return this.totalOffset().left;}
 Element.prototype.totalOffsetTop=function()
 {return this.totalOffset().top;}
@@ -615,6 +620,14 @@ Element.prototype.selectionLeftOffset=function()
 return null;var leftOffset=selection.anchorOffset;var node=selection.anchorNode;while(node!==this){while(node.previousSibling){node=node.previousSibling;leftOffset+=node.textContent.length;}
 node=node.parentNodeOrShadowHost();}
 return leftOffset;}
+HTMLImageElement.prototype.completePromise=function()
+{var element=this;if(element.complete)
+return Promise.resolve(element);return new Promise(promiseBody);function promiseBody(resolve)
+{element.addEventListener("load",oncomplete);element.addEventListener("error",oncomplete);function oncomplete()
+{resolve(element);}}}
+Node.prototype.appendChildren=function(var_args)
+{for(var i=0,n=arguments.length;i<n;++i)
+this.appendChild(arguments[i]);}
 Node.prototype.deepTextContent=function()
 {return this.childTextNodes().map(function(node){return node.textContent;}).join("");}
 Node.prototype.childTextNodes=function()
@@ -659,6 +672,9 @@ Event.prototype.deepElementFromPoint=function()
 node=node.parentNode;if(!node)
 return null;node=node.elementFromPoint(this.pageX,this.pageY);while(node&&node.shadowRoot)
 node=node.shadowRoot.elementFromPoint(this.pageX,this.pageY);return node;}
+Event.prototype.deepActiveElement=function()
+{var activeElement=this.target&&this.target.ownerDocument?this.target.ownerDocument.activeElement:null;while(activeElement&&activeElement.shadowRoot)
+activeElement=activeElement.shadowRoot.activeElement;return activeElement;}
 Document.prototype.deepElementFromPoint=function(x,y)
 {var node=this.elementFromPoint(x,y);while(node&&node.shadowRoot)
 node=node.shadowRoot.elementFromPoint(x,y);return node;}
